@@ -1,5 +1,4 @@
-#! /usr/bin/python
-# -*- coding: utf-8 -*-
+#! /usr/bin/python3
 # nautilus-scripts-manager
 #
 # nautilus-scripts-manager is free software; you can redistribute it and/or
@@ -15,13 +14,13 @@
 # with nautilus-scripts-manager; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 #
-# Copyright © 2011 Pietro Battiston <me@pietrobattiston.it>
+# Copyright © 2011-2014 Pietro Battiston <me@pietrobattiston.it>
 
-import gtk
+from gi.repository import Gtk
 
 class Ui(object):
     def __init__(self, APP, filename):
-        self._builder = gtk.Builder()
+        self._builder = Gtk.Builder()
         self._builder.set_translation_domain(APP)
         self._builder.add_from_file(filename)
     
@@ -34,4 +33,4 @@ class Ui(object):
                 self.obj = obj
                 return obj
             else:
-                raise AttributeError, "no object named \"%s\" in the GUI." % attr_name
+                raise AttributeError("no object named \"%s\" in the GUI." % attr_name)
